==> Paws-0.28.tar.gz: Paws-0.28/lib/Paws/DS/DescribeConditionalForwarders.pm <==

package Paws::DS::DescribeConditionalForwarders;
  use Moose;
  has DirectoryId => (is => 'ro', isa => 'Str', required => 1);
  has RemoteDomainNames => (is => 'ro', isa => 'ArrayRef[Str]');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeConditionalForwarders');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::DS::DescribeConditionalForwardersResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DS::DescribeConditionalForwarders - Arguments for method DescribeConditionalForwarders on Paws::DS

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeConditionalForwarders on the 
AWS Directory Service service. Use the attributes of this class
as arguments to method DescribeConditionalForwarders.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeConditionalForwarders.

As an example:

  $service_obj->DescribeConditionalForwarders(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> DirectoryId => Str

The directory ID for which to get the list of associated conditional
forwarders.



=head2 RemoteDomainNames => ArrayRef[Str]

The fully qualified domain names (FQDN) of the remote domains for which
to get the list of associated conditional forwarders. If this member is
null, all conditional forwarders are returned.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeConditionalForwarders in L<Paws::DS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.32.tar.gz: Paws-0.32/lib/Paws/DS/DescribeConditionalForwarders.pm <==

package Paws::DS::DescribeConditionalForwarders;
  use Moose;
  has DirectoryId => (is => 'ro', isa => 'Str', required => 1);
  has RemoteDomainNames => (is => 'ro', isa => 'ArrayRef[Str|Undef]');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeConditionalForwarders');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::DS::DescribeConditionalForwardersResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DS::DescribeConditionalForwarders - Arguments for method DescribeConditionalForwarders on Paws::DS

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeConditionalForwarders on the 
AWS Directory Service service. Use the attributes of this class
as arguments to method DescribeConditionalForwarders.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeConditionalForwarders.

As an example:

  $service_obj->DescribeConditionalForwarders(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> DirectoryId => Str

The directory ID for which to get the list of associated conditional
forwarders.



=head2 RemoteDomainNames => ArrayRef[Str|Undef]

The fully qualified domain names (FQDN) of the remote domains for which
to get the list of associated conditional forwarders. If this member is
null, all conditional forwarders are returned.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeConditionalForwarders in L<Paws::DS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
